# osh
# Copyright (C) 2005 Jack Orenstein <jao@geophile.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

"""Usage: py LINE_OF_PYTHON_CODE

The LINE_OF_PYTHON_CODE is executed. The main purpose of this command
is to define variables that can be used in subsequent osh commands.
Example:

    osh py 'a = 123; b = 456 ^ f '(a, b)' $

This command generates the output '(123, 456)'.
"""

import sys

import osh.oshargs
import osh.oshobjects

def py(*args):
    return _Py().process_args(*args)

class _Py(osh.oshobjects.Op):

    # object interface

    def __init__(self):
        osh.oshobjects.Op.__init__(self, '', (1, 1))


    # BaseOp interface
    
    def doc(self):
        return __doc__

    def setup(self):
        code = self.args().next_string()
        before = globals().copy()
        exec code in globals()
        after = globals()
        # Put new symbols in oshfunction.defined_by_osh
        for key, value in after.iteritems():
            if key not in before:
                osh.oshfunction.defined_by_osh[key] = value
    
    def receive(self, object):
        self.send(object)


    # Generator interface

    def execute(self):
        self.send(tuple()) # Have to send something
        self.send_complete()
